(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1566353,      43501]
NotebookOptionsPosition[   1558252,      43236]
NotebookOutlinePosition[   1558705,      43254]
CellTagsIndexPosition[   1558662,      43251]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Polynomial Factorization", "Title"],

Cell["\<\
This is a set of three programs which factor polynomials of several variables \
in certain cannonical forms. 
The programs are: FactTwoDim, FactTwoDimTwoRank and FactNDim.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Credits:", "Text"],

Cell["\<\
Author: Radoslaw Stefanski
Guidance: Prof. William T. Ross
Institution: University of Richmond
April 2004
email: rstefans@richmond.edu \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Section 1: Factorization of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"]}], ")"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{"f", "(", 
      SubscriptBox["x", "1"], ")"}], 
     RowBox[{"g", "(", 
      SubscriptBox["x", "2"], ")"}]}]}], TraditionalForm]]]
}], "Section"],

Cell[TextData[{
 "Here we factor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"]}], ")"}], TraditionalForm]]],
 ", a polynomial of two variables ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 ", as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     SubscriptBox["x", "1"], ")"}], 
    RowBox[{"g", "(", 
     SubscriptBox["x", "2"], ")"}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " are polynomials in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 " respectively. This type of factorization can occur if and only if the \
corresponding coefficient matrix (See Def. 2.4) is of rank one (see Thm. \
2.5). \nThe FactNDim program should be given a polynomial in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    FormBox["x",
     TraditionalForm], "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 " and the dimension of the polynomial - in this case two. If the polynomials \
is rank one, the program factorizes it and prints the resultant (factorized) \
polynomial. The program also contains an in-built error check. If there is \
some unexpected bug, and the program factors a polynomial incorrectly, the \
program lets the user know of the error, to avoid using incorrect results. If \
the rank is not one, the program prints \"The Polynomial is not of Rank 1\".  \
 "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Evaluate this cell before running FactNDim. Expand to view FactNDim and \
helper methods.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
     "This", " ", "following", " ", "HELPER", " ", "METHOD", " ", "takes", 
      " ", "a", " ", "vector", " ", "and", " ", "returns", " ", "the", " ", 
      "index", " ", "of", " ", "the", " ", "first", " ", "non"}], "-", 
     RowBox[{"zero", " ", 
      RowBox[{"element", ".", " ", "If"}], " ", "all", " ", "elements", " ", 
      "zero", " ", "returns", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "SmallText"], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"nonZeroElementIndex", "[", "em_", 
     RowBox[{"(*", 
      RowBox[{"a", " ", "matrix"}], "*)"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m", "=", "em"}], ",", "i", ",", "j", ",", "trigger", ",", 
        "dim", ",", "k", ",", "l"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"trigger", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"dim", "=", 
        RowBox[{"Dimensions", "[", "m", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", 
            RowBox[{"dim", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&&", 
           RowBox[{"trigger", "\[Equal]", "0"}]}], ")"}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"m", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
            RowBox[{"trigger", "++"}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"[", 
            RowBox[{"i", "-", "1"}], "]"}], "]"}], "==", "0"}], ",", " ", 
         RowBox[{
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"-", "1"}]}], "}"}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"i", "-", "1"}], ",", "1"}], "}"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["(*", "SmallText"], 
   RowBox[{
    StyleBox["This", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["is", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["the", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["helper", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["program", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["that", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["factors", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["a", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["polynomial", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["into", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["p", "SmallText"], 
    RowBox[{
     RowBox[{
      StyleBox["(", "SmallText"], 
      SubscriptBox[
       StyleBox["x", "SmallText"], "1"], ")"}], ".", "p"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "2"], "..."}], ",", 
      SubscriptBox["x", "n"]}], ")"}]}], " ", 
   StyleBox["*)", "SmallText"]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"FactTwoDimNEW", "[", 
     RowBox[{"poly_", ",", "labla_", ",", 
      RowBox[{"Optional", "[", 
       RowBox[{"second_", ",", "False"}], "]"}]}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pl", "=", "poly"}], ",", 
        RowBox[{"a", "=", "labla"}], ",", "b", ",", 
        RowBox[{"s", "=", "second"}], ",", "rank", ",", "m", ",", "mt", ",", 
        "\[Beta]", ",", "\[Gamma]", ",", "c", ",", "i", ",", "j", ",", 
        "expr1", ",", "expr2", ",", "ba"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"b", "=", 
        RowBox[{"a", "+", "1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"m", "=", 
        RowBox[{"CoefficientList", "[", 
         RowBox[{"pl", ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "a"], ",", 
            SubscriptBox["x", "b"]}], "}"}]}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Creates", " ", "a", " ", "Coefficient", " ", "Matrix", " ", "in", 
          " ", "lexicographical", " ", "order"}], "SmallText"], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"m", "//", "MatrixForm"}], "]"}], ";"}], "\t\t\t\t\t\t\t", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"rank", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Transpose", "[", "m", "]"}], " ", "]"}], "-", 
         RowBox[{"Length", "[", 
          RowBox[{"NullSpace", "[", "m", "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Calculates", " ", "the", " ", "Rank", " ", "of", " ", "the", " ", 
          "Coefficeint", " ", "Matrix"}], "SmallText"], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"rank", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"mt", "=", 
           RowBox[{"RowReduce", "[", 
            RowBox[{"Transpose", "[", "m", "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"\[Beta]", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"mt", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "i"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Transpose", "[", "mt", "]"}], "]"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Calculates", " ", "the", " ", "Betas"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
             RowBox[{
             "The", " ", "following", " ", "makes", " ", "a", " ", "call", 
              " ", "to", " ", "nonZeroElementIndex", " ", "and", " ", "gets", 
              " ", "the", " ", "first", " ", "non"}], "-", 
             RowBox[{
             "zero", " ", "row", " ", "in", " ", "the", " ", "Coefficient", 
              " ", "matrix"}], "  ", "-", " ", 
             RowBox[{
             "determined", " ", "via", " ", "the", " ", "beta", " ", 
              "vector"}]}], "SmallText"], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"ba", "=", 
           RowBox[{
            RowBox[{"nonZeroElementIndex", "[", "\[Beta]", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"m", "[", 
              RowBox[{"[", 
               RowBox[{"ba", ",", "k"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Transpose", "[", "m", "]"}], "]"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Calculates", " ", "the", " ", "Gammas"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"expr1", "=", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"expr2", "=", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", " ", "=", "1"}], ",", " ", 
            RowBox[{"i", "\[LessEqual]", " ", 
             RowBox[{"Length", "[", "\[Beta]", "\[NoBreak]", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", " ", 
            RowBox[{"expr1", "=", 
             RowBox[{"Expand", "[", " ", 
              RowBox[{"expr1", "+", 
               RowBox[{
                RowBox[{"\[Beta]", "\[NoBreak]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "*", 
                SuperscriptBox[
                 SubscriptBox["x", "a"], 
                 RowBox[{"i", "-", "1"}]]}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", " ", "=", "1"}], ",", " ", 
            RowBox[{"i", "\[LessEqual]", " ", 
             RowBox[{"Length", "[", "\[Gamma]", "\[NoBreak]", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", " ", 
            RowBox[{"expr2", "=", " ", 
             RowBox[{"Expand", "[", 
              RowBox[{"expr2", "+", 
               RowBox[{
                RowBox[{"\[Gamma]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "*", 
                SuperscriptBox[
                 SubscriptBox["x", "b"], 
                 RowBox[{"i", "-", "1"}]]}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"s", "\[Equal]", "False"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Return", "[", "expr1", "]"}], ";"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Return", "[", "expr2", "]"}]}], "\[IndentingNewLine]", 
           "]"}], ";"}], "\[IndentingNewLine]", ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Return", "[", "False", "]"}], ";"}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", "]"}], ";"}]}], 
     "\[IndentingNewLine]", "\t", "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NONRFE", "[", 
    RowBox[{"poly_", ",", "dimension_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"pl", "=", "poly"}], ",", 
       RowBox[{"dim", "=", "dimension"}], ",", "t", ",", "i", ",", "temp"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "dim"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"temp", "=", 
          RowBox[{"FactTwoDimNEW", "[", 
           RowBox[{"pl", ",", "i"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"temp", "\[Equal]", "False"}], ",", 
           RowBox[{
            RowBox[{"Return", "[", "]"}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"t", "=", 
          RowBox[{"t", "*", "temp"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"pl", "=", 
          RowBox[{"FactTwoDimNEW", "[", 
           RowBox[{"pl", ",", "i", ",", "True"}], "]"}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"t", "=", 
       RowBox[{"pl", "*", "t"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "t", "]"}], ";"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "This", " ", "method", " ", "is", " ", "a", " ", "master", " ", "method",
       " ", "that", " ", "performs", " ", "error", " ", 
      RowBox[{"checking", ".", " ", "If"}], " ", "error", " ", "checking", 
      " ", "is", " ", "wanted"}], ",", " ", 
     RowBox[{
      RowBox[{"add", " ", "the", " ", "boo"}], "=", 
      RowBox[{"true", " ", 
       RowBox[{"parameter", "."}]}]}]}], "*)"}], "SmallText"], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FactNDim", "[", 
     RowBox[{"poly_", ",", "dimension_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pl", "=", "poly"}], ",", 
        RowBox[{"dim", "=", "dimension"}], ",", " ", "finalexpr"}], "}"}], 
      ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"finalexpr", "=", 
        RowBox[{"NONRFE", "[", 
         RowBox[{"pl", ",", "dim"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<finalexpr: \>\"", ",", "finalexpr"}], "]"}], ";"}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"finalexpr", "\[Equal]", "Null"}], ",", 
         RowBox[{
          RowBox[{
          "Print", "[", "\"\<The polynomial is not of rank 1\>\"", "]"}], ";",
           " ", 
          RowBox[{"Print", "[", "pl", "]"}], ";"}]}], " ", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"finalexpr", "-", "pl"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Correctly Factorized\>\"", "]"}], ";", 
          " ", 
          RowBox[{"Print", "[", "finalexpr", "]"}], ";"}], " ", ",", " ", 
         RowBox[{
         "Print", "[", 
          "\"\<There is a either bug in the Program or you have mis-entered \
an instruction. Please check your input.\>\"", "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Subsection"],

Cell[TextData[{
 "Let us consider an example of how the program operates. Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"8", "+", 
     RowBox[{"12", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}], "-", 
     RowBox[{"4", 
      SubscriptBox["x", "1"]}], "-", 
     RowBox[{"6", 
      SubscriptBox["x", "1"], 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"8", 
      SubscriptBox["x", "1"], " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}], "+", 
     RowBox[{"6", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"]}], "+", 
     RowBox[{"9", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"], "*", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"12", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"], " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}]}]}], TraditionalForm]]],
 ". Running the program, we obtain:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{"8", "+", 
    RowBox[{"12", 
     SubscriptBox["x", "2"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox[
      SubscriptBox["x", "2"], "2"]}], "-", 
    RowBox[{"4", 
     SubscriptBox["x", "1"]}], "-", 
    RowBox[{"6", 
     SubscriptBox["x", "1"], 
     SubscriptBox["x", "2"]}], "-", 
    RowBox[{"8", 
     SubscriptBox["x", "1"], " ", 
     SuperscriptBox[
      SubscriptBox["x", "2"], "2"]}], "+", 
    RowBox[{"6", 
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"]}], "+", 
    RowBox[{"9", 
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"], "*", 
     SubscriptBox["x", "2"]}], "+", 
    RowBox[{"12", 
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"], " ", 
     SuperscriptBox[
      SubscriptBox["x", "2"], "2"]}]}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{"8", " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    FractionBox[
     SubscriptBox["x", "1"], "2"], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubsuperscriptBox["x", "1", "2"]}], "4"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubscriptBox["x", "2"]}], "2"], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "2", "2"]}]}], ")"}]}]], "Print"]
}, Open  ]],

Cell[TextData[{
 "How did the program obtain this result? First, a coefficient matrix, ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 ", is created from the polynomial, so that:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"8", "+", 
      RowBox[{"12", 
       SubscriptBox["x", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox[
        SubscriptBox["x", "2"], "2"]}], "-", 
      RowBox[{"4", 
       SubscriptBox["x", "1"]}], "-", 
      RowBox[{"6", 
       SubscriptBox["x", "1"], 
       SubscriptBox["x", "2"]}], "-", 
      RowBox[{"8", 
       SubscriptBox["x", "1"], " ", 
       SuperscriptBox[
        SubscriptBox["x", "2"], "2"]}], "+", 
      RowBox[{"6", 
       SuperscriptBox[
        SubscriptBox["x", "1"], "2"]}], "+", 
      RowBox[{"9", 
       SuperscriptBox[
        SubscriptBox["x", "1"], "2"], "*", 
       SubscriptBox["x", "2"]}], "+", 
      RowBox[{"12", 
       SuperscriptBox[
        SubscriptBox["x", "1"], "2"], " ", 
       SuperscriptBox[
        SubscriptBox["x", "2"], "2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["x", "2"]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"8", "12", "16"},
     {
      RowBox[{"-", "4"}], 
      RowBox[{"-", "6"}], 
      RowBox[{"-", "8"}]},
     {"6", "9", "12"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Next, the matrix ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 ", is column reduced to obtain:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{"RowReduce", "[", 
    RowBox[{"Transpose", "[", "m", "]"}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0"},
     {
      FractionBox["3", "4"], "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This initial column of the matrix are the coefficients for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    SubscriptBox["x", "1"], ")"}], TraditionalForm]]],
 ". Next, we look at the top row of ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " to obtain the coefficients of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    SubscriptBox["x", "2"], ")"}], TraditionalForm]]],
 ". To see why we doing this makes sense examine theorem Theorem 2.5 and \
Example 2.6. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection"],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"3", "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"]}], "+", 
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"], "-", 
     RowBox[{"15", " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"10", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}], "+", 
     RowBox[{"8", " ", 
      SubscriptBox["x", "1"], " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"], " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FactNDim", "[", 
   RowBox[{
    RowBox[{"3", "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"]}], "+", 
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"], "-", 
     RowBox[{"15", " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"10", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}], "+", 
     RowBox[{"8", " ", 
      SubscriptBox["x", "1"], " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       SubscriptBox["x", "1"], "2"], " ", 
      SuperscriptBox[
       SubscriptBox["x", "2"], "2"]}]}], ",", "2"}], "]"}], ";"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{"3", " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"]}], "3"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "1", "2"], "3"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    RowBox[{"5", " ", 
     SubscriptBox["x", "2"]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["x", "2", "2"]}]}], ")"}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsection"],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"], "-", 
     SuperscriptBox[
      SubscriptBox["x", "2"], "2"]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     SubscriptBox["x", "1"], "2"], "-", 
    SuperscriptBox[
     SubscriptBox["x", "2"], "2"]}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData["\<\"The polynomial is not of rank 1\"\>"], "Print"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["x", "1", "2"], "-", 
  SubsuperscriptBox["x", "2", "2"]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Subsection"],

Cell[TextData[{
 "Entering polynomials of one variable, constants or already factorized \
polynomials, simply returns the functions or constants in an unchanged state. \
Factorization is then reported as \"Correctly Factorized\". \nWe enter the \
polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    SubscriptBox["x", "1"]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   SubscriptBox["x", "1"], ",", "2"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 SubscriptBox["x", "1"]], "Print"]
}, Open  ]],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"5", "+", "3"}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{"5", "+", "3"}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData["8"], "Print"]
}, Open  ]],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{
     SubscriptBox["x", "1"], "*", 
     SubscriptBox["x", "2"]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "*", 
    SubscriptBox["x", "2"]}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["x", "1"], " ", 
  SubscriptBox["x", "2"]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 5", "Subsection"],

Cell[TextData[{
 "If more than one variable, say ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "3"], TraditionalForm]]],
 ", is entered, the program assumes the variable is a constant and factorizes \
in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDim", "[", 
  RowBox[{
   RowBox[{"3", " ", 
    SubscriptBox["x", "1"]}], "+", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"]}], "-", 
   RowBox[{"3", " ", 
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "3"]}], "-", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"], " ", 
    SubscriptBox["x", "3"]}], "+", 
   RowBox[{"3", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "3", "2"]}], "+", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"], " ", 
    SubsuperscriptBox["x", "3", "2"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["x", "1"], " ", 
  RowBox[{"(", 
   RowBox[{"3", "-", 
    RowBox[{"3", " ", 
     SubscriptBox["x", "3"]}], "+", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["x", "3", "2"]}], "+", 
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["x", "3"], "+", 
       SubsuperscriptBox["x", "3", "2"]}], ")"}]}]}], ")"}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell["Let us now consider some heftier examples.", "Text"],

Cell[CellGroupData[{

Cell["Example 6", "Subsection"],

Cell[TextData[{
 " We enter the polynomial: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"2", "+", 
     SubscriptBox["x", "1"], "+", 
     SubsuperscriptBox["x", "1", "2"], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"]}], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SubsuperscriptBox["x", "1", "5"]}], "5"], "+", 
     RowBox[{"8", " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"16", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      FractionBox["12", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      FractionBox["3", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      FractionBox["3", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "2", "5"]}], "-", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "5"]}], "-", 
     RowBox[{
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "5"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubsuperscriptBox["x", "2", "5"]}], "-", 
     RowBox[{
      FractionBox["3", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "5"]}]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDim", "[", 
  RowBox[{"2", "+", 
   SubscriptBox["x", "1"], "+", 
   SubsuperscriptBox["x", "1", "2"], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SubsuperscriptBox["x", "1", "5"]}], "5"], "+", 
   RowBox[{"8", " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"4", " ", 
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubscriptBox["x", "2"]}], "-", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{
    FractionBox["12", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    FractionBox["3", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    FractionBox["3", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["x", "2", "5"]}], "-", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "5"]}], "-", 
   RowBox[{
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "5"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubsuperscriptBox["x", "2", "5"]}], "-", 
   RowBox[{
    FractionBox["3", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "5"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "1"], "2"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "1", "2"], "2"], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "1", "4"]}], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubsuperscriptBox["x", "1", "5"]}], "10"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    RowBox[{"8", " ", 
     SubscriptBox["x", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "2", "2"]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "2", "3"]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "2", "5"]}]}], ")"}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 7", "Subsection"],

Cell[TextData[{
 "We enter the polynomial: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"1400", "+", 
     RowBox[{"2100", " ", 
      SubscriptBox["x", "1"]}], "+", 
     RowBox[{"40", " ", 
      SubsuperscriptBox["x", "1", "5"]}], "+", 
     RowBox[{"100", " ", 
      SubsuperscriptBox["x", "1", "7"]}], "-", 
     RowBox[{"400", " ", 
      SubsuperscriptBox["x", "1", "10"]}], "+", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{"5894", " ", 
      SubsuperscriptBox["x", "2", "10"]}], "+", 
     RowBox[{"8841", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "+", 
     RowBox[{
      FractionBox["842", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "+", 
     RowBox[{"421", " ", 
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "-", 
     RowBox[{"1684", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "-", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "100"]}], "-", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "-", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "-", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "+", 
     RowBox[{"1988", " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "+", 
     RowBox[{"2982", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "+", 
     RowBox[{
      FractionBox["284", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "+", 
     RowBox[{"142", " ", 
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "-", 
     RowBox[{"568", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}]}]}], TraditionalForm]]],
 " \ninto our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDim", "[", 
  RowBox[{"1400", "+", 
   RowBox[{"2100", " ", 
    SubscriptBox["x", "1"]}], "+", 
   RowBox[{"40", " ", 
    SubsuperscriptBox["x", "1", "5"]}], "+", 
   RowBox[{"100", " ", 
    SubsuperscriptBox["x", "1", "7"]}], "-", 
   RowBox[{"400", " ", 
    SubsuperscriptBox["x", "1", "10"]}], "+", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{"5894", " ", 
    SubsuperscriptBox["x", "2", "10"]}], "+", 
   RowBox[{"8841", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "+", 
   RowBox[{
    FractionBox["842", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "+", 
   RowBox[{"421", " ", 
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "-", 
   RowBox[{"1684", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "-", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "100"]}], "-", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "-", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "-", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "+", 
   RowBox[{"1988", " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "+", 
   RowBox[{"2982", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "+", 
   RowBox[{
    FractionBox["284", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "+", 
   RowBox[{"142", " ", 
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "-", 
   RowBox[{"568", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubscriptBox["x", "1"]}], "2"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "1", "5"], "35"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "1", "7"], "14"], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "1", "10"]}], "7"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1400", "+", 
    RowBox[{"14", " ", 
     SubsuperscriptBox["x", "2", "2"]}], "+", 
    RowBox[{"14", " ", 
     SubsuperscriptBox["x", "2", "3"]}], "+", 
    RowBox[{"5894", " ", 
     SubsuperscriptBox["x", "2", "10"]}], "-", 
    RowBox[{"14", " ", 
     SubsuperscriptBox["x", "2", "33"]}], "-", 
    RowBox[{"14", " ", 
     SubsuperscriptBox["x", "2", "100"]}], "+", 
    RowBox[{"1988", " ", 
     SubsuperscriptBox["x", "2", "9873"]}]}], ")"}]}]], "Print"]
}, Open  ]],

Cell["\<\
Notice, that the above calculation took about a minute to a minute and a half \
to run. This is still remarkably efficient, when considering the complexity \
of the system. \
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Section 2: Factorization of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"]}], ")"}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "r"], 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "i"], "(", 
      SubscriptBox["x", "1"], ")"}], 
     RowBox[{
      SubscriptBox["g", "i"], "(", 
      SubscriptBox["x", "2"], ")"}]}]}], TraditionalForm]]]
}], "Section"],

Cell[TextData[{
 "Here we factor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"]}], ")"}], TraditionalForm]]],
 ", as the minimum sum of rank one polynomials (see Thm. 2.5), ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "r"], 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "i"], "(", 
      SubscriptBox["x", "1"], ")"}], 
     RowBox[{
      SubscriptBox["g", "i"], "(", 
      SubscriptBox["x", "2"], ")"}]}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["g", "i"], TraditionalForm]]],
 " are polynomials in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 " respectively. This minimum number of rank one polynomials is called the \
rank of the polynomial (see Def. 2.9) . This type of factorization can occur \
if and only if the corresponding coefficient matrix (See Def. 2.4) is of rank \
",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " (see Thm. 2.11).\nThe ",
 "FactTwoDimTwoRank",
 " program should be given a polynomial in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    FormBox["x",
     TraditionalForm], "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "2"], TraditionalForm]]],
 ". If the polynomials is rank r, the program factorizes it and prints the \
resultant (factorized) polynomial and its rank. The program also contains an \
in-built error check. If there is some unexpected bug, and the program \
factors a polynomial incorrectly, the program lets the user know of the \
error, to avoid using incorrect results. The polynomial can also factor rank \
one polynomials - hence, it can completely replace ",
 "FactTwoDim",
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Evaluate this cell before running FactTwoDimTwoRank. Expand to view \
FactTwoDimTwoRank and helper methods.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
     "This", " ", "following", " ", "HELPER", " ", "METHOD", " ", "takes", 
      " ", "a", " ", "vector", " ", "and", " ", "returns", " ", "the", " ", 
      "index", " ", "of", " ", "the", " ", "first", " ", "non"}], "-", 
     RowBox[{"zero", " ", 
      RowBox[{"element", ".", " ", "If"}], " ", "all", " ", "elements", " ", 
      "zero", " ", "returns", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "SmallText"], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"nonZeroElementIndex", "[", "em_", 
      RowBox[{"(*", 
       RowBox[{"a", " ", "matrix"}], "*)"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m", "=", "em"}], ",", "i", ",", "j", ",", "trigger", ",", 
         "dim", ",", "k", ",", "l"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"trigger", "=", "0"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"dim", "=", 
         RowBox[{"Dimensions", "[", "m", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"\"\<m \>\"", ",", 
            RowBox[{"m", " ", "//", "MatrixForm"}]}], "]"}], ";"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"\"\<*dim[[1]] \>\"", ",", 
            RowBox[{"dim", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"i", "\[LessEqual]", 
             RowBox[{"dim", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "&&", 
            RowBox[{"trigger", "\[Equal]", "0"}]}], ")"}], ",", 
          RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"m", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
             RowBox[{"trigger", "++"}]}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "[", 
            RowBox[{"[", 
             RowBox[{"i", "-", "1"}], "]"}], "]"}], "==", "0"}], ",", " ", 
          RowBox[{
           RowBox[{"Return", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", 
              RowBox[{"-", "1"}]}], "}"}], "]"}], ";"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", "-", "1"}], ",", "1"}], "}"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", 
     RowBox[{
      StyleBox["This", "SmallText"], 
      StyleBox[" ", "SmallText"], 
      StyleBox["HELPER", "SmallText"], 
      StyleBox["  ", "SmallText"], 
      StyleBox["METHOD", "SmallText"], 
      StyleBox[" ", "SmallText"], 
      StyleBox["is", "SmallText"], 
      StyleBox[" ", "SmallText"], 
      StyleBox["essentially", "SmallText"], 
      StyleBox[" ", "SmallText"], 
      StyleBox["identical", "SmallText"], 
      StyleBox[" ", "SmallText"], 
      StyleBox["to", "SmallText"], 
      StyleBox[" ", "SmallText"], "FactTwoDim", " ", "except", " ", "that", 
      " ", "it", " ", "already", " ", "takes", " ", "a", " ", "coefficient", 
      " ", "matrix", " ", "instead", " ", "of", " ", "a", " ", "polynomial"}],
      "*)"}], "SmallText"], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Sympl", "[", "polymatrix_", "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m", "=", "polymatrix"}], ",", "rank", ",", "mt", ",", 
        "\[Beta]", ",", "\[Gamma]", ",", "i", ",", "j", ",", "expr1", ",", 
        "expr2", ",", "ba"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"CoefficientList", "[", 
          RowBox[{"pl", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}], ";"}], " ", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Creates", " ", "a", " ", "Coefficient", " ", "Matrix", " ", "in", 
          " ", "lexicographical", " ", "order"}], "SmallText"], "*)"}], 
       "*)"}], "\[IndentingNewLine]", "\t\t\t\t\t\t\t", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rank", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Transpose", "[", "m", "]"}], " ", "]"}], "-", 
         RowBox[{"Length", "[", 
          RowBox[{"NullSpace", "[", "m", "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Calculates", " ", "the", " ", "Rank", " ", "of", " ", "the", " ", 
          "Coefficeint", " ", "Matrix"}], "SmallText"], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"rank", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"mt", "=", 
           RowBox[{"RowReduce", "[", 
            RowBox[{"Transpose", "[", "m", "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"\[Beta]", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"mt", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "i"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Transpose", "[", "mt", "]"}], "]"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Calculates", " ", "the", " ", "Betas"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
             RowBox[{
             "The", " ", "foloowing", " ", "loop", " ", "finds", " ", "the", 
              " ", "first", " ", "non"}], "-", 
             RowBox[{
             "zero", " ", "row", " ", "in", " ", "the", " ", "Coefficient", 
              " ", "matrix"}]}], "SmallText"], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"ba", "=", 
           RowBox[{
            RowBox[{"nonZeroElementIndex", "[", "\[Beta]", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"m", "[", 
              RowBox[{"[", 
               RowBox[{"ba", ",", "k"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Transpose", "[", "m", "]"}], "]"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Calculates", " ", "the", " ", "Gammas"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"expr1", "=", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"expr2", "=", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", " ", "=", "1"}], ",", " ", 
            RowBox[{"i", "\[LessEqual]", " ", 
             RowBox[{"Length", "[", "\[Beta]", "\[NoBreak]", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", " ", 
            RowBox[{"expr1", "=", " ", 
             RowBox[{"expr1", "+", 
              RowBox[{
               RowBox[{"\[Beta]", "\[NoBreak]", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               SuperscriptBox[
                SubscriptBox["x", "1"], 
                RowBox[{"i", "-", "1"}]]}]}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", " ", "=", "1"}], ",", " ", 
            RowBox[{"i", "\[LessEqual]", " ", 
             RowBox[{"Length", "[", "\[Gamma]", "\[NoBreak]", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", " ", 
            RowBox[{"expr2", "=", " ", 
             RowBox[{"expr2", "+", 
              RowBox[{
               RowBox[{"\[Gamma]", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               SuperscriptBox[
                SubscriptBox["x", "2"], 
                RowBox[{"i", "-", "1"}]]}]}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Return", "[", 
           RowBox[{"expr1", "*", "expr2"}], "]"}], ";"}], 
         "\[IndentingNewLine]", ",", " ", 
         RowBox[{
         "Print", "[", "\"\<The Coefficient Matrix is not of Rank 1\>\"", 
          "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "\t", "]"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"FactTwoDimTwoRank", "::", "usage"}], "=", 
     "\"\<The method \!\(\*\n\
StyleBox[\\\"FRankver1\\\",\\nFontSlant->\\\"Italic\\\"]\) factors \
polynomials in two variables (in x and y) and of any rank into sums of \
products of polynomials in one variable. That is, \n FRankver1[poly(x,y)]= \!\
\(\*UnderoverscriptBox[\(\[Sum]\), \(i = 1\), \
\(k\)]\)\!\(\*SubscriptBox[\(p\), \(i\)]\)(x)\!\(\*SubscriptBox[\(q\), \(i\)]\
\)(y),\nwhere k is the rank of the coefficient matrix of the function \
poly(x,y) \>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{"FactTwoDimTwoRank", "[", "poly_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pl", "=", "poly"}], ",", "m", ",", "rank", ",", "i", ",", 
        "j", ",", "t", ",", "dimt", ",", "temp", ",", "ranktemp", ",", "sol", 
        ",", "final", ",", "k", ",", " ", "finalParts", ",", "answer", ",", 
        "isTrue"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"CoefficientList", "[", 
         RowBox[{"pl", ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "1"], ",", 
            SubscriptBox["x", "2"]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"m", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"rank", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Transpose", "[", "m", "]"}], " ", "]"}], "-", 
         RowBox[{"Length", "[", 
          RowBox[{"NullSpace", "[", "m", "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<rank=\>\"", ",", "rank"}], "]"}], ";"}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"rank", "\[NotEqual]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          StyleBox[
           RowBox[{
           "t", " ", "determines", " ", "the", " ", "basis", " ", "vectors", 
            " ", "for", " ", "the", " ", "coefficient", " ", "matrix"}], 
           "SmallText"], "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"t", "=", 
           RowBox[{"Transpose", "[", 
            RowBox[{"RowReduce", "[", 
             RowBox[{"Transpose", "[", "m", "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\t", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"t", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Dimensions", " ", "of", " ", "t"}], "SmallText"], "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{"dimt", "=", 
           RowBox[{"Dimensions", "[", "t", "]"}]}], ";", 
          "\[IndentingNewLine]", "\t", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<dim2= \>\"", ",", 
              RowBox[{"dimt", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
             RowBox[{"Declaration", " ", "of", " ", "final"}], ",", " ", 
             RowBox[{
             "a", " ", "matrix", " ", "that", " ", "will", " ", "hold", " ", 
              "the", " ", "seperated", " ", "matrices", " ", "used", " ", 
              "in", " ", "the", " ", "final", " ", "calculation"}]}], 
            "SmallText"], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"final", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", " ", 
                 RowBox[{"dimt", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], " ", "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", " ", 
                 RowBox[{"dimt", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], " ", "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", "rank"}], " ", "}"}]}], "]"}]}], 
          ";", "\[IndentingNewLine]", "\t", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<final= \>\"", ",", 
              RowBox[{"final", "//", "MatrixForm"}]}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
            "A", " ", "temporary", " ", "variable", " ", "that", " ", "puts", 
             " ", "all", " ", "basis", " ", "vectors", " ", "as", " ", 
             "columns", " ", "into", " ", "one", " ", "matrix"}], 
            "SmallText"], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"temp", "=", 
           RowBox[{"Transpose", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"t", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "j"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "1", ",", "rank"}], "}"}]}], "]"}], "]"}]}], 
          ";", "\[IndentingNewLine]", "\t", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<temp=\>\"", ",", 
              RowBox[{"temp", "//", "MatrixForm"}]}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
            "A", " ", "variable", " ", "that", " ", "determines", " ", "the", 
             " ", "coefficient", " ", "matrices", " ", "of", " ", "each", " ",
              "element", " ", "in", " ", "the", " ", "sum"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", "=", "1"}], ",", 
            RowBox[{"i", "\[LessEqual]", 
             RowBox[{"dimt", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"sol", "=", 
              RowBox[{"LinearSolve", "[", 
               RowBox[{"temp", ",", 
                RowBox[{"m", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "i"}], "]"}], "]"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", "\t", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Print", "[", 
                RowBox[{"\"\<temp=\>\"", ",", 
                 RowBox[{"temp", "//", "MatrixForm"}]}], "]"}], ";", 
               "\[IndentingNewLine]", "\t", 
               RowBox[{"Print", "[", 
                RowBox[{"\"\<sol=\>\"", ",", " ", 
                 RowBox[{"sol", "//", "MatrixForm"}]}], "]"}], ";"}], "*)"}], 
             "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", 
             RowBox[{"For", "[", 
              RowBox[{
               RowBox[{"j", "=", "1"}], ",", 
               RowBox[{"j", "\[LessEqual]", "rank"}], ",", 
               RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "\t", 
               RowBox[{
                RowBox[{
                 RowBox[{"final", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "i"}], "]"}], "]"}], "=", 
                 RowBox[{
                  RowBox[{"sol", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "*", 
                  RowBox[{"temp", "[", 
                   RowBox[{"[", 
                    RowBox[{"All", ",", "j"}], "]"}], "]"}]}]}], ";"}]}], 
              "\[IndentingNewLine]", "     \t", "]"}]}]}], 
           "\[IndentingNewLine]", "      ", "]"}], ";", "\[IndentingNewLine]",
           "\[IndentingNewLine]", "\t", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<final=\>\"", ",", 
              RowBox[{"final", "//", "MatrixForm"}]}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
            "A", " ", "variable", " ", "that", " ", "stores", " ", "the", " ",
              "factorization", " ", "to", " ", "be", " ", "printed"}], 
            "SmallText"], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"answer", "=", "0"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"j", "=", "1"}], ",", 
            RowBox[{"j", "\[LessEqual]", "rank"}], ",", 
            RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", " ", 
            RowBox[{
             RowBox[{"answer", "=", 
              RowBox[{"answer", "+", 
               RowBox[{"(", 
                RowBox[{"Sympl", "[", 
                 RowBox[{"Transpose", "[", 
                  RowBox[{"final", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "]"}], "]"}], ")"}]}]}], 
             ";"}]}], "\[IndentingNewLine]", " ", "]"}]}], 
         "\[IndentingNewLine]", "\[IndentingNewLine]", ",", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"IF", " ", "RANK"}], "\[Equal]", "1"}], "*)"}], " ", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          StyleBox[
           RowBox[{
           "A", " ", "variable", " ", "that", " ", "stores", " ", "the", " ", 
            "factorization", " ", "to", " ", "be", " ", "printed"}], 
           "SmallText"], "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"answer", "=", 
           RowBox[{"Sympl", "[", "m", "]"}]}], ";"}]}], "\[IndentingNewLine]",
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Determines", " ", "whether", " ", "factorization", " ", "was", " ", 
          "succesful"}], "SmallText"], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "answer", "]"}], "-", "poly"}], "\[Equal]", 
          "0"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Correctly Factorized\>\"", "]"}], ";"}], 
         ",", " ", 
         RowBox[{
          RowBox[{
          "Print", "[", 
           "\"\<There is a bug in the Program. Please email: \
rstefans@richmond.edu and report it.\>\"", "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", 
             RowBox[{"(", 
              RowBox[{"answer", "-", "poly"}], ")"}], "]"}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{"isTrue", "=", "True"}], ",", 
           RowBox[{"isTrue", "=", "False"}], ",", 
           RowBox[{"isTrue", "=", "False"}]}], "]"}], ";"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
          RowBox[{
          "Prints", " ", "out", " ", "whether", " ", "factorization", " ", 
           "was", " ", "true", " ", "or", " ", "not"}], ",", " ", 
          RowBox[{
          "the", " ", "polynomial", " ", "that", " ", "was", " ", 
           "entererd"}], ",", " ", 
          RowBox[{"and", " ", "the", " ", "final", " ", "factorization"}]}], 
         "SmallText"], 
        StyleBox[" ", "SmallText"], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"StylePrint", "[", 
          RowBox[{"isTrue", " ", ",", 
           RowBox[{"FontWeight", "->", "Bold"}]}], "]"}], ";"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<rank= \>\"", ",", "rank"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"StylePrint", "[", 
          RowBox[{
           RowBox[{"\"\<Entered Polynomial: \>\"", 
            RowBox[{"Expand", "[", "poly", "]"}]}], ",", 
           RowBox[{"FontSlant", "\[Rule]", "Italic"}]}], "]"}], ";"}], "*)"}],
        "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "answer", "]"}], ";"}]}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", "]"}]}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Subsection"],

Cell[TextData[{
 "Examining Theorem 2.11, we can see that any two dimensional rank ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " matrix can be written as the sum of ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " rank one matrices. The program, ",
 "FactTwoDimTwoRank",
 ", works by creating a coefficient matrix, ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 ", for the entered polynomial. It then rewrites this matrix as the sum of ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " rank one matrices. Each rank one matrix, in turn, corresponds to a rank \
one polynomial (see Thm. 2.5) . Each rank one matrix is then processed (as in \
section 1) to obtain its corresponding factorized polynomial. The resultant \
factorized rank ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " polynomial is simply the sum of the ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " rank ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " polynomials."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection"],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "2"]}], "+", 
     SubsuperscriptBox["x", "1", "3"], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"5", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"7", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"10", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     SubsuperscriptBox["x", "2", "3"], "+", 
     RowBox[{"12", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "7"]}]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  RowBox[{"1", "+", 
   RowBox[{"2", " ", 
    SubscriptBox["x", "1"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "2"]}], "+", 
   SubsuperscriptBox["x", "1", "3"], "+", 
   RowBox[{"2", " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"3", " ", 
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"5", " ", 
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"7", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"10", " ", 
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   SubsuperscriptBox["x", "2", "3"], "+", 
   RowBox[{"12", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "7"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["rank= ", 4],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"1", "+", 
  SubsuperscriptBox["x", "1", "3"], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"]}], "+", 
  SubsuperscriptBox["x", "2", "3"], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"4", "+", 
     RowBox[{"5", " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"10", " ", 
      SubsuperscriptBox["x", "2", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"3", " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"7", " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"12", " ", 
      SubsuperscriptBox["x", "2", "7"]}]}], ")"}]}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsection"],

Cell[TextData[{
 "Entering polynomials of one variable, constants or already factorized \
polynomials, simply returns the functions or constants in an unchanged state. \
Factorization is then reported as \"Correctly Factorized\". \nWe enter the \
polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    SubscriptBox["x", "1"]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  SubscriptBox["x", "1"], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["rank= ", 1],
  Editable->False]], "Print"],

Cell[BoxData[
 SubscriptBox["x", "1"]], "Print"]
}, Open  ]],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", 
    RowBox[{"5", "+", "3"}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  RowBox[{"5", "+", "3"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["rank= ", 1],
  Editable->False]], "Print"],

Cell[BoxData["8"], "Print"]
}, Open  ]],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{
     SubscriptBox["x", "1"], "*", 
     SubscriptBox["x", "2"]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  RowBox[{
   SubscriptBox["x", "1"], "*", 
   SubscriptBox["x", "2"]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["rank= ", 1],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["x", "1"], " ", 
  SubscriptBox["x", "2"]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Subsection"],

Cell[TextData[{
 "An interesting fact is that if a polynomial is enetered in three or more \
dimensions, then ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]]],
 "'s for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", ">", "3"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]]],
 " is taken to be constant. As such, a function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"], ",", 
     SubscriptBox["x", "3"]}], ")"}], TraditionalForm]]],
 ", is factorized as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["p", "1"], "(", 
     SubscriptBox["x", "1"], ")"}], 
    RowBox[{
     SubscriptBox["p", "2"], "(", 
     RowBox[{
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"]}], ")"}]}], TraditionalForm]]],
 " by the program. \nFor instance, if we enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"10", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"10", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"15", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "3"]}], "+", 
     RowBox[{"15", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "3"]}]}]}], TraditionalForm]]],
 "into our program, we obtain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  RowBox[{
   RowBox[{"10", " ", 
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"10", " ", 
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"15", " ", 
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "3"]}], "+", 
   RowBox[{"15", " ", 
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubscriptBox["x", "3"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["rank= ", 1],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "1"], "+", 
    SubsuperscriptBox["x", "1", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"10", " ", 
     SubscriptBox["x", "2"]}], "+", 
    RowBox[{"15", " ", 
     SubscriptBox["x", "3"]}]}], ")"}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell["Let us now consider some heftier examples.", "Text"],

Cell[CellGroupData[{

Cell["Example 5", "Subsection"],

Cell[TextData[{
 " We enter the polynomial: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"2", "+", 
     SubscriptBox["x", "1"], "+", 
     SubsuperscriptBox["x", "1", "2"], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "3"]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SubsuperscriptBox["x", "1", "5"]}], "5"], "+", 
     SubsuperscriptBox["x", "1", "6"], "+", 
     RowBox[{"8", " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{"16", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      FractionBox["12", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      FractionBox["3", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      FractionBox["3", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "2", "5"]}], "-", 
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "5"]}], "-", 
     RowBox[{
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "5"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"], " ", 
      SubsuperscriptBox["x", "2", "5"]}], "-", 
     RowBox[{
      FractionBox["4", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "5"]}]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  RowBox[{"2", "+", 
   SubscriptBox["x", "1"], "+", 
   SubsuperscriptBox["x", "1", "2"], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "3"]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "1", "5"]}], "5"], "+", 
   SubsuperscriptBox["x", "1", "6"], "+", 
   RowBox[{"8", " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"4", " ", 
    SubscriptBox["x", "1"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubscriptBox["x", "2"]}], "-", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{
    FractionBox["12", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubscriptBox["x", "2"]}], "+", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    FractionBox["3", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    FractionBox["3", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["x", "2", "5"]}], "-", 
   RowBox[{
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "5"]}], "-", 
   RowBox[{
    SubsuperscriptBox["x", "1", "2"], " ", 
    SubsuperscriptBox["x", "2", "5"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "4"], " ", 
    SubsuperscriptBox["x", "2", "5"]}], "-", 
   RowBox[{
    FractionBox["4", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "5"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["rank= ", 4],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"2", "-", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["x", "1", "3"], "-", 
     SubsuperscriptBox["x", "1", "4"], "-", 
     FractionBox[
      SubsuperscriptBox["x", "1", "6"], "4"]}], ")"}]}], "+", 
  RowBox[{"8", " ", 
   SubscriptBox["x", "2"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"]}], "-", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "5"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "1"], "+", 
     SubsuperscriptBox["x", "1", "2"], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "4"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"4", " ", 
      SubscriptBox["x", "2"]}], "+", 
     SubsuperscriptBox["x", "2", "2"], "+", 
     SubsuperscriptBox["x", "2", "3"], "-", 
     SubsuperscriptBox["x", "2", "5"]}], ")"}]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["2", "5"], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       SubscriptBox["x", "2"]}], "5"], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SubsuperscriptBox["x", "2", "2"]}], "5"], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SubsuperscriptBox["x", "2", "3"]}], "5"], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       SubsuperscriptBox["x", "2", "5"]}], "5"]}], ")"}]}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 6", "Subsection"],

Cell[TextData[{
 " We enter the polynomial: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"]}], ")"}], "=", 
    RowBox[{"1400", "+", 
     RowBox[{"2100", " ", 
      SubscriptBox["x", "1"]}], "+", 
     RowBox[{"40", " ", 
      SubsuperscriptBox["x", "1", "5"]}], "+", 
     RowBox[{"120", " ", 
      SubsuperscriptBox["x", "1", "7"]}], "-", 
     RowBox[{"400", " ", 
      SubsuperscriptBox["x", "1", "11"]}], "+", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{"5894", " ", 
      SubsuperscriptBox["x", "2", "10"]}], "+", 
     RowBox[{"8841", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "+", 
     RowBox[{
      FractionBox["842", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "+", 
     RowBox[{"421", " ", 
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "-", 
     RowBox[{"1684", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "10"]}], "-", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "100"]}], "-", 
     RowBox[{"21", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "-", 
     RowBox[{
      FractionBox["2", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "-", 
     RowBox[{
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "100"]}], "+", 
     RowBox[{"1988", " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "+", 
     RowBox[{"2982", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "+", 
     RowBox[{
      FractionBox["284", "5"], " ", 
      SubsuperscriptBox["x", "1", "5"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "+", 
     RowBox[{"142", " ", 
      SubsuperscriptBox["x", "1", "7"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}], "-", 
     RowBox[{"568", " ", 
      SubsuperscriptBox["x", "1", "10"], " ", 
      SubsuperscriptBox["x", "2", "9873"]}]}]}], TraditionalForm]]],
 " \ninto our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactTwoDimTwoRank", "[", 
  RowBox[{"1400", "+", 
   RowBox[{"2100", " ", 
    SubscriptBox["x", "1"]}], "+", 
   RowBox[{"40", " ", 
    SubsuperscriptBox["x", "1", "5"]}], "+", 
   RowBox[{"120", " ", 
    SubsuperscriptBox["x", "1", "7"]}], "-", 
   RowBox[{"400", " ", 
    SubsuperscriptBox["x", "1", "11"]}], "+", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "2"]}], "+", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "3"]}], "+", 
   RowBox[{"5894", " ", 
    SubsuperscriptBox["x", "2", "10"]}], "+", 
   RowBox[{"8841", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "+", 
   RowBox[{
    FractionBox["842", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "+", 
   RowBox[{"421", " ", 
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "-", 
   RowBox[{"1684", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "10"]}], "-", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "33"]}], "-", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["x", "2", "100"]}], "-", 
   RowBox[{"21", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "-", 
   RowBox[{
    FractionBox["2", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "-", 
   RowBox[{
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "100"]}], "+", 
   RowBox[{"1988", " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "+", 
   RowBox[{"2982", " ", 
    SubscriptBox["x", "1"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "+", 
   RowBox[{
    FractionBox["284", "5"], " ", 
    SubsuperscriptBox["x", "1", "5"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "+", 
   RowBox[{"142", " ", 
    SubsuperscriptBox["x", "1", "7"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}], "-", 
   RowBox[{"568", " ", 
    SubsuperscriptBox["x", "1", "10"], " ", 
    SubsuperscriptBox["x", "2", "9873"]}]}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"rank= \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["rank= ", 2],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["x", "1", "7"], "+", 
     RowBox[{"20", " ", 
      SubsuperscriptBox["x", "1", "10"]}], "-", 
     RowBox[{"20", " ", 
      SubsuperscriptBox["x", "1", "11"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"120", "+", 
     SubsuperscriptBox["x", "2", "2"], "+", 
     SubsuperscriptBox["x", "2", "3"], "+", 
     RowBox[{"421", " ", 
      SubsuperscriptBox["x", "2", "10"]}], "-", 
     SubsuperscriptBox["x", "2", "33"], "-", 
     SubsuperscriptBox["x", "2", "100"], "+", 
     RowBox[{"142", " ", 
      SubsuperscriptBox["x", "2", "9873"]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SubscriptBox["x", "1"]}], "2"], "+", 
     FractionBox[
      SubsuperscriptBox["x", "1", "5"], "35"], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       SubsuperscriptBox["x", "1", "10"]}], "7"], "+", 
     FractionBox[
      RowBox[{"10", " ", 
       SubsuperscriptBox["x", "1", "11"]}], "7"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1400", "+", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "2"]}], "+", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "3"]}], "+", 
     RowBox[{"5894", " ", 
      SubsuperscriptBox["x", "2", "10"]}], "-", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "33"]}], "-", 
     RowBox[{"14", " ", 
      SubsuperscriptBox["x", "2", "100"]}], "+", 
     RowBox[{"1988", " ", 
      SubsuperscriptBox["x", "2", "9873"]}]}], ")"}]}]}]], "Print"]
}, Open  ]],

Cell["Notice that the above calculation took five minutes. ", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Section 3: Factorization of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", "...", " ", ",", 
     SubscriptBox["x", "n"]}], ")"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["f", "1"], "(", 
       SubscriptBox["x", "1"], ")"}], "..."}], 
     RowBox[{
      SubscriptBox["f", "n"], "(", 
      SubscriptBox["x", "n"], ")"}]}]}], TraditionalForm]]]
}], "Section"],

Cell[TextData[{
 "Here we factor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", "...", " ", ",", 
     SubscriptBox["x", "n"]}], ")"}], TraditionalForm]]],
 ", a polynomial of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " variables ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 " through ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "n"], TraditionalForm]]],
 ", as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["f", "1"], "(", 
      SubscriptBox["x", "1"], ")"}], "..."}], 
    RowBox[{
     SubscriptBox["f", "n"], "(", 
     SubscriptBox["x", "n"], ")"}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 " is a polynomial in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "1"], TraditionalForm]]],
 ", for all ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". \nThe FactNDim program should be given a polynomial in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    FormBox["x",
     TraditionalForm], "1"], TraditionalForm]]],
 " through ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "n"], TraditionalForm]]],
 " and the dimension of the polynomial as a number. NOTE: IT IS CRUCIAL THAT \
THE RIGHT DIMENSION IS GIVEN - if an incorrect dimension is passed, the \
program will NOT function properly. Hence, the program rests on the \
programming mantra :  \"Garbage in, garbage out\". \nIf the polynomials is \
rank one, the program factorizes it and prints the resultant (factorized) \
polynomial. It also makes sure the polynomial was correctly factorized and \
displays \"Correctly Factorized\" if it was. The program also contains an \
in-built error check. If there is some unexpected bug, and the program \
factors a polynomial incorrectly, the program lets the user know of the \
error, to avoid using incorrect results. If the rank is not one, the program \
prints \"The Polynomial is not of Rank 1\"."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Evaluate this cell before running FactNDim. Expand to view FactNDim and \
helper methods.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   StyleBox[
    RowBox[{
     RowBox[{
     "This", " ", "following", " ", "HELPER", " ", "METHOD", " ", "takes", 
      " ", "a", " ", "vector", " ", "and", " ", "returns", " ", "the", " ", 
      "index", " ", "of", " ", "the", " ", "first", " ", "non"}], "-", 
     RowBox[{"zero", " ", 
      RowBox[{"element", ".", " ", "If"}], " ", "all", " ", "elements", " ", 
      "zero", " ", "returns", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "SmallText"], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"nonZeroElementIndex", "[", "em_", 
     RowBox[{"(*", 
      RowBox[{"a", " ", "matrix"}], "*)"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m", "=", "em"}], ",", "i", ",", "j", ",", "trigger", ",", 
        "dim", ",", "k", ",", "l"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"trigger", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"dim", "=", 
        RowBox[{"Dimensions", "[", "m", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", 
            RowBox[{"dim", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&&", 
           RowBox[{"trigger", "\[Equal]", "0"}]}], ")"}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"m", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[NotEqual]", "0"}], ",", 
            RowBox[{"trigger", "++"}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"[", 
            RowBox[{"i", "-", "1"}], "]"}], "]"}], "==", "0"}], ",", " ", 
         RowBox[{
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"-", "1"}]}], "}"}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"i", "-", "1"}], ",", "1"}], "}"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["(*", "SmallText"], 
   RowBox[{
    StyleBox["This", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["is", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["the", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["helper", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["program", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["that", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["factors", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["a", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["polynomial", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["into", "SmallText"], 
    StyleBox[" ", "SmallText"], 
    StyleBox["p", "SmallText"], 
    RowBox[{
     RowBox[{
      StyleBox["(", "SmallText"], 
      SubscriptBox[
       StyleBox["x", "SmallText"], "1"], ")"}], ".", "p"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "2"], "..."}], ",", 
      SubscriptBox["x", "n"]}], ")"}]}], " ", 
   StyleBox["*)", "SmallText"]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"FactTwoDimNEW", "[", 
     RowBox[{"poly_", ",", "labla_", ",", 
      RowBox[{"Optional", "[", 
       RowBox[{"second_", ",", "False"}], "]"}]}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pl", "=", "poly"}], ",", 
        RowBox[{"a", "=", "labla"}], ",", "b", ",", 
        RowBox[{"s", "=", "second"}], ",", "rank", ",", "m", ",", "mt", ",", 
        "\[Beta]", ",", "\[Gamma]", ",", "c", ",", "i", ",", "j", ",", 
        "expr1", ",", "expr2", ",", "ba"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"b", "=", 
        RowBox[{"a", "+", "1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"m", "=", 
        RowBox[{"CoefficientList", "[", 
         RowBox[{"pl", ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["x", "a"], ",", 
            SubscriptBox["x", "b"]}], "}"}]}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Creates", " ", "a", " ", "Coefficient", " ", "Matrix", " ", "in", 
          " ", "lexicographical", " ", "order"}], "SmallText"], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"m", "//", "MatrixForm"}], "]"}], ";"}], "\t\t\t\t\t\t\t", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"rank", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Transpose", "[", "m", "]"}], " ", "]"}], "-", 
         RowBox[{"Length", "[", 
          RowBox[{"NullSpace", "[", "m", "]"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        StyleBox[
         RowBox[{
         "Calculates", " ", "the", " ", "Rank", " ", "of", " ", "the", " ", 
          "Coefficeint", " ", "Matrix"}], "SmallText"], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"rank", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"mt", "=", 
           RowBox[{"RowReduce", "[", 
            RowBox[{"Transpose", "[", "m", "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"\[Beta]", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"mt", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "i"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Transpose", "[", "mt", "]"}], "]"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Calculates", " ", "the", " ", "Betas"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{
             RowBox[{
             "The", " ", "following", " ", "makes", " ", "a", " ", "call", 
              " ", "to", " ", "nonZeroElementIndex", " ", "and", " ", "gets", 
              " ", "the", " ", "first", " ", "non"}], "-", 
             RowBox[{
             "zero", " ", "row", " ", "in", " ", "the", " ", "Coefficient", 
              " ", "matrix"}], "  ", "-", " ", 
             RowBox[{
             "determined", " ", "via", " ", "the", " ", "beta", " ", 
              "vector"}]}], "SmallText"], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"ba", "=", 
           RowBox[{
            RowBox[{"nonZeroElementIndex", "[", "\[Beta]", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"m", "[", 
              RowBox[{"[", 
               RowBox[{"ba", ",", "k"}], "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Transpose", "[", "m", "]"}], "]"}]}], "}"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           StyleBox[
            RowBox[{"Calculates", " ", "the", " ", "Gammas"}], "SmallText"], 
           "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"expr1", "=", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"expr2", "=", "0"}], ";", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", " ", "=", "1"}], ",", " ", 
            RowBox[{"i", "\[LessEqual]", " ", 
             RowBox[{"Length", "[", "\[Beta]", "\[NoBreak]", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", " ", 
            RowBox[{"expr1", "=", 
             RowBox[{"Expand", "[", " ", 
              RowBox[{"expr1", "+", 
               RowBox[{
                RowBox[{"\[Beta]", "\[NoBreak]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "*", 
                SuperscriptBox[
                 SubscriptBox["x", "a"], 
                 RowBox[{"i", "-", "1"}]]}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", " ", "=", "1"}], ",", " ", 
            RowBox[{"i", "\[LessEqual]", " ", 
             RowBox[{"Length", "[", "\[Gamma]", "\[NoBreak]", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", " ", 
            RowBox[{"expr2", "=", " ", 
             RowBox[{"Expand", "[", 
              RowBox[{"expr2", "+", 
               RowBox[{
                RowBox[{"\[Gamma]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "*", 
                SuperscriptBox[
                 SubscriptBox["x", "b"], 
                 RowBox[{"i", "-", "1"}]]}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"s", "\[Equal]", "False"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Return", "[", "expr1", "]"}], ";"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Return", "[", "expr2", "]"}]}], "\[IndentingNewLine]", 
           "]"}], ";"}], "\[IndentingNewLine]", ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Return", "[", "False", "]"}], ";"}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", "]"}], ";"}]}], 
     "\[IndentingNewLine]", "\t", "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NONRFE", "[", 
    RowBox[{"poly_", ",", "dimension_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"pl", "=", "poly"}], ",", 
       RowBox[{"dim", "=", "dimension"}], ",", "t", ",", "i", ",", "temp"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "dim"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"temp", "=", 
          RowBox[{"FactTwoDimNEW", "[", 
           RowBox[{"pl", ",", "i"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"temp", "\[Equal]", "False"}], ",", 
           RowBox[{
            RowBox[{"Return", "[", "]"}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"t", "=", 
          RowBox[{"t", "*", "temp"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"pl", "=", 
          RowBox[{"FactTwoDimNEW", "[", 
           RowBox[{"pl", ",", "i", ",", "True"}], "]"}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"t", "=", 
       RowBox[{"pl", "*", "t"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "t", "]"}], ";"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "This", " ", "method", " ", "is", " ", "a", " ", "master", " ", "method",
       " ", "that", " ", "performs", " ", "error", " ", 
      RowBox[{"checking", ".", " ", "If"}], " ", "error", " ", "checking", 
      " ", "is", " ", "wanted"}], ",", " ", 
     RowBox[{
      RowBox[{"add", " ", "the", " ", "boo"}], "=", 
      RowBox[{"true", " ", 
       RowBox[{"parameter", "."}]}]}]}], "*)"}], "SmallText"], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FactNDim", "[", 
     RowBox[{"poly_", ",", "dimension_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pl", "=", "poly"}], ",", 
        RowBox[{"dim", "=", "dimension"}], ",", " ", "finalexpr"}], "}"}], 
      ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"finalexpr", "=", 
        RowBox[{"NONRFE", "[", 
         RowBox[{"pl", ",", "dim"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<finalexpr: \>\"", ",", "finalexpr"}], "]"}], ";"}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"finalexpr", "\[Equal]", "Null"}], ",", 
         RowBox[{
          RowBox[{
          "Print", "[", "\"\<The polynomial is not of rank 1\>\"", "]"}], ";",
           " ", 
          RowBox[{"Print", "[", "pl", "]"}], ";"}]}], " ", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"finalexpr", "-", "pl"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Correctly Factorized\>\"", "]"}], ";", 
          " ", 
          RowBox[{"Print", "[", "finalexpr", "]"}], ";"}], " ", ",", " ", 
         RowBox[{
         "Print", "[", 
          "\"\<There is a either bug in the Program or you have mis-entered \
an instruction. Please check your input.\>\"", "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Subsection"],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", 
      SubscriptBox["x", "4"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"6", " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"6", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"6", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "2", "2"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["x", "1"], " ", 
      SubsuperscriptBox["x", "2", "2"], " ", 
      SubscriptBox["x", "4"]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["x", "1", "2"], " ", 
      SubsuperscriptBox["x", "2", "2"], " ", 
      SubscriptBox["x", "4"]}]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"6", " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"6", " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"6", " ", 
     SubsuperscriptBox["x", "1", "2"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "1", "2"], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "2", "2"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["x", "1"], " ", 
     SubsuperscriptBox["x", "2", "2"], " ", 
     SubscriptBox["x", "4"]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["x", "1", "2"], " ", 
     SubsuperscriptBox["x", "2", "2"], " ", 
     SubscriptBox["x", "4"]}]}], ",", "4"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{"6", " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "1"], "+", 
    SubsuperscriptBox["x", "1", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "2"], "3"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "2", "2"], "3"]}], ")"}], " ", 
  SubscriptBox["x", "4"]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection"],

Cell[TextData[{
 "We enter the following polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"]}], ")"}], "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["x", "1"], "2"], "-", 
     SuperscriptBox[
      SubscriptBox["x", "2"], "2"], "-", 
     SuperscriptBox[
      SubscriptBox["x", "3"], "3"]}]}], TraditionalForm]]],
 "that is not of rank 1 into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     SubscriptBox["x", "1"], "2"], "-", 
    SuperscriptBox[
     SubscriptBox["x", "2"], "2"], "-", 
    SuperscriptBox[
     SubscriptBox["x", "3"], "3"]}], ",", "3"}], "]"}]], "Input"],

Cell[BoxData["\<\"The polynomial is not of rank 1\"\>"], "Print"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["x", "1", "2"], "-", 
  SubsuperscriptBox["x", "2", "2"], "-", 
  SubsuperscriptBox["x", "3", "3"]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsection"],

Cell[TextData[{
 "Entering polynomials of one variable or a constant  simply returns the \
functions or constant in an unchanged state. Factorization is then reported \
as \"Correctly Factorized\". \nWe enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     SubscriptBox["x", "1"], ")"}], "=", 
    SubscriptBox["x", "1"]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   SubscriptBox["x", "1"], ",", "1"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 SubscriptBox["x", "1"]], "Print"]
}, Open  ]],

Cell[TextData[{
 "We enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", "...", ",", 
      SubscriptBox["x", "n"]}], ")"}], "=", 
    RowBox[{"5", "+", "3"}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{"5", "+", "3"}], ",", "1"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData["8"], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Subsection"],

Cell[TextData[{
 "Entering polynomials that are already factorized, expands the polynomial \
and factorizes them again. Factorization is then reported as \"Correctly \
Factorized\". \nWe enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", 
      SubscriptBox["x", "4"], ",", 
      SubscriptBox["x", "5"], ",", 
      SubscriptBox["x", "6"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], "+", "1", "+", 
       RowBox[{
        SubscriptBox["x", "1"], "^", "4"}]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], "+", 
       RowBox[{
        SubscriptBox["x", "2"], "^", "2"}], "+", "1"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "3"], "+", 
       RowBox[{
        SubscriptBox["x", "3"], "^", "2"}]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "4"], "+", 
       RowBox[{
        SubscriptBox["x", "4"], "^", "2"}], "+", "3"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "5"], "+", "1", "+", 
       RowBox[{
        SubscriptBox["x", "5"], "^", "2"}]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "6"], "^", "2"}], "+", 
       SubscriptBox["x", "6"], "+", "2"}], ")"}]}]}], TraditionalForm]]],
 " into our program, to obain the following output:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "1"], "+", "1", "+", 
      RowBox[{
       SubscriptBox["x", "1"], "^", "4"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "2"], "+", 
      RowBox[{
       SubscriptBox["x", "2"], "^", "2"}], "+", "1"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "3"], "+", 
      RowBox[{
       SubscriptBox["x", "3"], "^", "2"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "4"], "+", 
      RowBox[{
       SubscriptBox["x", "4"], "^", "2"}], "+", "3"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "5"], "+", "1", "+", 
      RowBox[{
       SubscriptBox["x", "5"], "^", "2"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "6"], "^", "2"}], "+", 
      SubscriptBox["x", "6"], "+", "2"}], ")"}]}], ",", "6"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{"6", " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "1"], "+", 
    SubsuperscriptBox["x", "1", "4"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "2"], "+", 
    SubsuperscriptBox["x", "2", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "3"], "+", 
    SubsuperscriptBox["x", "3", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "4"], "3"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "4", "2"], "3"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "5"], "+", 
    SubsuperscriptBox["x", "5", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "6"], "2"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "6", "2"], "2"]}], ")"}]}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 5", "Subsection"],

Cell[TextData[{
 "Let us now test, a rather hefty example! \nWe enter the polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["x", "3"], ",", 
      SubscriptBox["x", "4"], ",", 
      SubscriptBox["x", "5"], ",", 
      SubscriptBox["x", "6"], ",", 
      SubscriptBox["x", "7"], ",", 
      SubscriptBox["x", "8"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "1"], "+", 
       SubsuperscriptBox["x", "1", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "2"], "+", 
       SubsuperscriptBox["x", "2", "2"], "+", 
       SubsuperscriptBox["x", "2", "3"]}], ")"}], " ", 
     SubscriptBox["x", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "3"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SubscriptBox["x", "4"], "+", 
       SubsuperscriptBox["x", "4", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "5"], "+", 
       SubsuperscriptBox["x", "5", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubscriptBox["x", "6"], "+", 
       SubsuperscriptBox["x", "6", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubscriptBox["x", "7"], "+", 
       SubsuperscriptBox["x", "7", "4"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         SubscriptBox["x", "8"], "8"]}], "+", 
       SubscriptBox["x", "8"]}], ")"}]}]}], TraditionalForm]]],
 " into our program. To see how large this polynomial is and what it looks \
like expanded,"
}], "Text"],

Cell[CellGroupData[{

Cell["click here!", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FormBox[
    RowBox[{
     RowBox[{"p", "(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["x", "3"], ",", 
       SubscriptBox["x", "4"], ",", 
       SubscriptBox["x", "5"], ",", 
       SubscriptBox["x", "6"], ",", 
       SubscriptBox["x", "7"], ",", 
       SubscriptBox["x", "8"]}], ")"}], "=", " "}],
    TraditionalForm], "36", " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"36", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"18", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"9", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"4", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubscriptBox["x", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"12", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubscriptBox["x", "7"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"6", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubscriptBox["x", "6"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubscriptBox["x", "5"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"3", " ", "\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubscriptBox["x", "4"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubscriptBox["x", "3"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubscriptBox["x", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "2"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubscriptBox["x", "1"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}], "+", 
  RowBox[{"\[Pi]", " ", 
   SubsuperscriptBox["x", "1", "4"], " ", 
   SubsuperscriptBox["x", "2", "3"], " ", 
   SubsuperscriptBox["x", "3", "2"], " ", 
   SubsuperscriptBox["x", "4", "2"], " ", 
   SubsuperscriptBox["x", "5", "2"], " ", 
   SubsuperscriptBox["x", "6", "2"], " ", 
   SubsuperscriptBox["x", "7", "4"], " ", 
   SubsuperscriptBox["x", "8", "8"]}]}]], "SmallText"]
}, Closed]],

Cell["\<\
We enter the polynomial in the form Expand[p], so as to save space and to \
give you and idea how fast the program is. The effect identical had we \
entered the polynomial in expanded form.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FactNDim", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "1"], "+", 
       SubsuperscriptBox["x", "1", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "2"], "+", 
       SubsuperscriptBox["x", "2", "2"], "+", 
       SubsuperscriptBox["x", "2", "3"]}], ")"}], " ", 
     SubscriptBox["x", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "3"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SubscriptBox["x", "4"], "+", 
       SubsuperscriptBox["x", "4", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["x", "5"], "+", 
       SubsuperscriptBox["x", "5", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubscriptBox["x", "6"], "+", 
       SubsuperscriptBox["x", "6", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SubscriptBox["x", "7"], "+", 
       SubsuperscriptBox["x", "7", "4"]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"Pi", "*", 
        SuperscriptBox[
         SubscriptBox["x", "8"], "8"]}], "+", 
       SubscriptBox["x", "8"]}], ")"}]}], "]"}], ",", "8"}], "]"}]], "Input"],

Cell[BoxData["\<\"Correctly Factorized\"\>"], "Print"],

Cell[BoxData[
 RowBox[{"36", " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "1"], "+", 
    SubsuperscriptBox["x", "1", "4"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "2"], "+", 
    SubsuperscriptBox["x", "2", "2"], "+", 
    SubsuperscriptBox["x", "2", "3"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "3"], "+", 
    SubsuperscriptBox["x", "3", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "4"], "3"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "4", "2"], "3"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SubscriptBox["x", "5"], "+", 
    SubsuperscriptBox["x", "5", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "6"], "2"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "6", "2"], "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "7"], "2"], "+", 
    FractionBox[
     SubsuperscriptBox["x", "7", "4"], "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     SubscriptBox["x", "8"], "3"], "+", 
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      SubsuperscriptBox["x", "8", "8"]}], "3"]}], ")"}]}]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1280, 951},
WindowMargins->{{41, Automatic}, {Automatic, 9}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 41, 0, 55, "Title"],
Cell[589, 22, 195, 4, 55, "Text"],
Cell[CellGroupData[{
Cell[809, 30, 24, 0, 25, "Text"],
Cell[836, 32, 159, 6, 145, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1032, 43, 428, 16, 54, "Section"],
Cell[1463, 61, 1785, 57, 117, "Text"],
Cell[CellGroupData[{
Cell[3273, 122, 119, 3, 52, "Subsection"],
Cell[3395, 127, 2524, 68, 250, "Input"],
Cell[5922, 197, 7637, 188, 716, "Input"],
Cell[13562, 387, 1522, 38, 270, "Input"],
Cell[15087, 427, 2224, 57, 250, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[17348, 489, 31, 0, 36, "Subsection"],
Cell[17382, 491, 1103, 37, 29, "Text"],
Cell[CellGroupData[{
Cell[18510, 532, 849, 29, 51, "Input"],
Cell[19362, 563, 54, 0, 25, "Print"],
Cell[19419, 565, 441, 15, 41, "Print"]
}, Open  ]],
Cell[19875, 583, 197, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[20097, 592, 1126, 37, 71, "Input"],
Cell[21226, 631, 288, 11, 93, "Output"]
}, Open  ]],
Cell[21529, 645, 133, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[21687, 654, 173, 5, 50, "Input"],
Cell[21863, 661, 292, 11, 111, "Output"]
}, Open  ]],
Cell[22170, 675, 512, 16, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22719, 696, 31, 0, 52, "Subsection"],
Cell[22753, 698, 1095, 36, 29, "Text"],
Cell[CellGroupData[{
Cell[23873, 738, 907, 29, 51, "Input"],
Cell[24783, 769, 54, 0, 25, "Print"],
Cell[24840, 771, 416, 14, 41, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25305, 791, 31, 0, 52, "Subsection"],
Cell[25339, 793, 422, 15, 29, "Text"],
Cell[CellGroupData[{
Cell[25786, 812, 210, 7, 51, "Input"],
Cell[25999, 821, 65, 0, 25, "Print"],
Cell[26067, 823, 113, 3, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26229, 832, 31, 0, 52, "Subsection"],
Cell[26263, 834, 531, 14, 60, "Text"],
Cell[CellGroupData[{
Cell[26819, 852, 107, 3, 50, "Input"],
Cell[26929, 857, 54, 0, 25, "Print"],
Cell[26986, 859, 48, 1, 25, "Print"]
}, Open  ]],
Cell[27049, 863, 316, 11, 29, "Text"],
Cell[CellGroupData[{
Cell[27390, 878, 108, 3, 50, "Input"],
Cell[27501, 883, 54, 0, 25, "Print"],
Cell[27558, 885, 27, 0, 25, "Print"]
}, Open  ]],
Cell[27600, 888, 366, 13, 29, "Text"],
Cell[CellGroupData[{
Cell[27991, 905, 156, 5, 50, "Input"],
Cell[28150, 912, 54, 0, 25, "Print"],
Cell[28207, 914, 93, 3, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28349, 923, 31, 0, 52, "Subsection"],
Cell[28383, 925, 391, 15, 29, "Text"],
Cell[CellGroupData[{
Cell[28799, 944, 642, 21, 51, "Input"],
Cell[29444, 967, 54, 0, 25, "Print"],
Cell[29501, 969, 425, 14, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[29953, 987, 58, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[30036, 991, 31, 0, 52, "Subsection"],
Cell[30070, 993, 2686, 78, 58, "Text"],
Cell[CellGroupData[{
Cell[32781, 1075, 2320, 69, 65, "Input"],
Cell[35104, 1146, 54, 0, 25, "Print"],
Cell[35161, 1148, 685, 22, 41, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35895, 1176, 31, 0, 52, "Subsection"],
Cell[35929, 1178, 3987, 109, 89, "Text"],
Cell[CellGroupData[{
Cell[39941, 1291, 3558, 100, 130, "Input"],
Cell[43502, 1393, 54, 0, 25, "Print"],
Cell[43559, 1395, 882, 27, 41, "Print"]
}, Open  ]],
Cell[44456, 1425, 197, 4, 29, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[44702, 1435, 553, 21, 36, "Section"],
Cell[45258, 1458, 1987, 63, 117, "Text"],
Cell[CellGroupData[{
Cell[47270, 1525, 137, 3, 52, "Subsection"],
Cell[47410, 1530, 21928, 526, 2221, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[69375, 2061, 31, 0, 36, "Subsection"],
Cell[69409, 2063, 998, 28, 67, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70444, 2096, 31, 0, 52, "Subsection"],
Cell[70478, 2098, 1206, 36, 29, "Text"],
Cell[CellGroupData[{
Cell[71709, 2138, 933, 27, 51, "Input"],
Cell[72645, 2167, 54, 0, 25, "Print"],
Cell[72702, 2169, 148, 4, 25, "Print"],
Cell[72853, 2175, 787, 25, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[73689, 2206, 31, 0, 52, "Subsection"],
Cell[73723, 2208, 531, 14, 60, "Text"],
Cell[CellGroupData[{
Cell[74279, 2226, 92, 2, 50, "Input"],
Cell[74374, 2230, 54, 0, 25, "Print"],
Cell[74431, 2232, 148, 4, 25, "Print"],
Cell[74582, 2238, 48, 1, 25, "Print"]
}, Open  ]],
Cell[74645, 2242, 208, 7, 29, "Text"],
Cell[CellGroupData[{
Cell[74878, 2253, 93, 2, 50, "Input"],
Cell[74974, 2257, 54, 0, 25, "Print"],
Cell[75031, 2259, 148, 4, 25, "Print"],
Cell[75182, 2265, 27, 0, 25, "Print"]
}, Open  ]],
Cell[75224, 2268, 366, 13, 29, "Text"],
Cell[CellGroupData[{
Cell[75615, 2285, 139, 4, 50, "Input"],
Cell[75757, 2291, 54, 0, 25, "Print"],
Cell[75814, 2293, 148, 4, 25, "Print"],
Cell[75965, 2299, 93, 3, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76107, 2308, 31, 0, 52, "Subsection"],
Cell[76141, 2310, 1666, 57, 60, "Text"],
Cell[CellGroupData[{
Cell[77832, 2371, 465, 14, 51, "Input"],
Cell[78300, 2387, 54, 0, 25, "Print"],
Cell[78357, 2389, 148, 4, 25, "Print"],
Cell[78508, 2395, 303, 11, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[78838, 2410, 58, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[78921, 2414, 31, 0, 52, "Subsection"],
Cell[78955, 2416, 2659, 77, 58, "Text"],
Cell[CellGroupData[{
Cell[81639, 2497, 2302, 68, 99, "Input"],
Cell[83944, 2567, 54, 0, 25, "Print"],
Cell[84001, 2569, 148, 4, 25, "Print"],
Cell[84152, 2575, 1411, 45, 41, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85612, 2626, 31, 0, 52, "Subsection"],
Cell[85646, 2628, 3988, 109, 89, "Text"],
Cell[CellGroupData[{
Cell[89659, 2741, 3565, 100, 130, "Input"],
Cell[93227, 2843, 54, 0, 25, "Print"],
Cell[93284, 2845, 148, 4, 25, "Print"],
Cell[93435, 2851, 1582, 47, 41, "Print"]
}, Open  ]],
Cell[95032, 2901, 69, 0, 29, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[95150, 2907, 523, 19, 34, "Section"],
Cell[95676, 2928, 2055, 62, 129, "Text"],
Cell[CellGroupData[{
Cell[97756, 2994, 119, 3, 52, "Subsection"],
Cell[97878, 2999, 2524, 68, 250, "Input"],
Cell[100405, 3069, 7637, 188, 716, "Input"],
Cell[108045, 3259, 1522, 38, 270, "Input"],
Cell[109570, 3299, 2224, 57, 250, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[111831, 3361, 31, 0, 36, "Subsection"],
Cell[111865, 3363, 1418, 43, 29, "Text"],
Cell[CellGroupData[{
Cell[113308, 3410, 1108, 33, 51, "Input"],
Cell[114419, 3445, 54, 0, 25, "Print"],
Cell[114476, 3447, 369, 12, 41, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[114894, 3465, 31, 0, 52, "Subsection"],
Cell[114928, 3467, 552, 18, 29, "Text"],
Cell[CellGroupData[{
Cell[115505, 3489, 271, 9, 51, "Input"],
Cell[115779, 3500, 65, 0, 25, "Print"],
Cell[115847, 3502, 155, 4, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[116051, 3512, 31, 0, 52, "Subsection"],
Cell[116085, 3514, 444, 11, 60, "Text"],
Cell[CellGroupData[{
Cell[116554, 3529, 107, 3, 50, "Input"],
Cell[116664, 3534, 54, 0, 25, "Print"],
Cell[116721, 3536, 48, 1, 25, "Print"]
}, Open  ]],
Cell[116784, 3540, 328, 11, 29, "Text"],
Cell[CellGroupData[{
Cell[117137, 3555, 108, 3, 50, "Input"],
Cell[117248, 3560, 54, 0, 25, "Print"],
Cell[117305, 3562, 27, 0, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117381, 3568, 31, 0, 52, "Subsection"],
Cell[117415, 3570, 1532, 47, 60, "Text"],
Cell[CellGroupData[{
Cell[118972, 3621, 984, 33, 50, "Input"],
Cell[119959, 3656, 54, 0, 25, "Print"],
Cell[120016, 3658, 875, 29, 41, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120940, 3693, 31, 0, 52, "Subsection"],
Cell[120974, 3695, 1775, 53, 79, "Text"],
Cell[CellGroupData[{
Cell[122774, 3752, 27, 0, 29, "Text"],
Cell[122804, 3754, 1432493, 39380, 7578, "SmallText"]
}, Closed]],
Cell[1555312, 43137, 213, 4, 28, "Text"],
Cell[CellGroupData[{
Cell[1555550, 43145, 1305, 39, 51, "Input"],
Cell[1556858, 43186, 54, 0, 25, "Print"],
Cell[1556915, 43188, 1297, 43, 41, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)

